@@ -7,13 +7,16 @@ from django.shortcuts import redirect, render
 from django.utils.html import format_html
 from django.utils.translation import gettext_lazy
 from django.views.decorators.http import require_POST
+from esi.decorators import token_required
+from eveuniverse.models import EveType
 
 from allianceauth.authentication.decorators import permissions_required
 from allianceauth.authentication.models import CharacterOwnership
 from allianceauth.eveonline.models import EveCharacter, EveCorporationInfo
 from allianceauth.services.hooks import get_extension_logger
-from esi.decorators import token_required
-from eveuniverse.models import EveType
+from app_utils.allianceauth import notify_admins
+from app_utils.logging import LoggerAddTag
+from app_utils.messages import messages_plus
 
 from .. import __title__, tasks
 from ..app_settings import (
@@ -23,7 +26,6 @@ from ..app_settings import (
     BLUEPRINTS_PAGING_ENABLED,
 )
 from ..models import Blueprint, Owner, Request
-from ..utils import LoggerAddTag, messages_plus, notify_admins
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
@@ -32,12 +34,7 @@ logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 @permissions_required("blueprints.basic_access")
 def index(request):
     if request.user.has_perm("blueprints.manage_requests"):
-        request_count = (
-            Request.objects.all().requests_fulfillable_by_user(request.user).count()
-            + Request.objects.all()
-            .requests_being_fulfilled_by_user(request.user)
-            .count()
-        )
+        request_count = Request.objects.open_requests_total_count(request.user)
     else:
         request_count = None
     context = {
@@ -451,7 +448,7 @@ def list_open_requests(request):
 
 
 def mark_request(
-    request, request_id, status, fulfilling_user, closed, *, can_requestor_edit=False
+    request, request_id, status, fulfulling_user, closed, *, can_requestor_edit=False
 ):
     completed = False
     user_request = Request.objects.get(pk=request_id)
@@ -479,7 +476,7 @@ def mark_request(
             user_request.closed_at = datetime.utcnow()
         else:
             user_request.closed_at = None
-        user_request.fulfulling_user = fulfilling_user
+        user_request.fulfulling_user = fulfulling_user
         user_request.status = status
         user_request.save()
         completed = True
